# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/elasticsearch/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.mdb.elasticsearch.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_backup__pb2
from yandex.cloud.mdb.elasticsearch.v1 import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_cluster__pb2
from yandex.cloud.mdb.elasticsearch.v1.config import elasticsearch_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_config_dot_elasticsearch__pb2
from yandex.cloud.mdb.elasticsearch.v1 import extension_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_extension__pb2
from yandex.cloud.mdb.elasticsearch.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_maintenance__pb2
from yandex.cloud.mdb.elasticsearch.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_user__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/mdb/elasticsearch/v1/cluster_service.proto\x12!yandex.cloud.mdb.elasticsearch.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/api/operation.proto\x1a.yandex/cloud/mdb/elasticsearch/v1/backup.proto\x1a/yandex/cloud/mdb/elasticsearch/v1/cluster.proto\x1a<yandex/cloud/mdb/elasticsearch/v1/config/elasticsearch.proto\x1a\x31yandex/cloud/mdb/elasticsearch/v1/extension.proto\x1a\x33yandex/cloud/mdb/elasticsearch/v1/maintenance.proto\x1a,yandex/cloud/mdb/elasticsearch/v1/user.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"m\n\x14ListClustersResponse\x12<\n\x08\x63lusters\x18\x01 \x03(\x0b\x32*.yandex.cloud.mdb.elasticsearch.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x82\x07\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x90\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x43.yandex.cloud.mdb.elasticsearch.v1.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12K\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x36.yandex.cloud.mdb.elasticsearch.v1.Cluster.Environment\x12H\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32-.yandex.cloud.mdb.elasticsearch.v1.ConfigSpecB\x04\xe8\xc7\x31\x01\x12?\n\nuser_specs\x18\x08 \x03(\x0b\x32+.yandex.cloud.mdb.elasticsearch.v1.UserSpec\x12G\n\nhost_specs\x18\t \x03(\x0b\x32+.yandex.cloud.mdb.elasticsearch.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12 \n\nnetwork_id\x18\n \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x0b \x03(\t\x12\x1a\n\x12service_account_id\x18\x0c \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\r \x01(\x08\x12P\n\x12maintenance_window\x18\x0e \x01(\x0b\x32\x34.yandex.cloud.mdb.elasticsearch.v1.MaintenanceWindow\x12I\n\x0f\x65xtension_specs\x18\x0f \x03(\x0b\x32\x30.yandex.cloud.mdb.elasticsearch.v1.ExtensionSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\x08\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\x84\x05\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x90\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x43.yandex.cloud.mdb.elasticsearch.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12H\n\x0b\x63onfig_spec\x18\x05 \x01(\x0b\x32\x33.yandex.cloud.mdb.elasticsearch.v1.ConfigSpecUpdate\x12(\n\x04name\x18\x06 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1a\n\x12security_group_ids\x18\x07 \x03(\t\x12\x1a\n\x12service_account_id\x18\x08 \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x12P\n\x12maintenance_window\x18\n \x01(\x0b\x32\x34.yandex.cloud.mdb.elasticsearch.v1.MaintenanceWindow\x12\x1c\n\nnetwork_id\x18\x0b \x01(\tB\x08\x8a\xc8\x31\x04<=50\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xd0\x03\n\x16ListClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12-\n\tfrom_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\tpage_size\x18\x05 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1e\n\x16\x61lways_next_page_token\x18\x07 \x01(\x08\x12\x1a\n\x06\x66ilter\x18\x08 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12[\n\x0cservice_type\x18\t \x01(\x0e\x32\x45.yandex.cloud.mdb.elasticsearch.v1.ListClusterLogsRequest.ServiceType\"J\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x11\n\rELASTICSEARCH\x10\x01\x12\n\n\x06KIBANA\x10\x02\"\xb6\x01\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12J\n\x07message\x18\x02 \x03(\x0b\x32\x39.yandex.cloud.mdb.elasticsearch.v1.LogRecord.MessageEntry\x1a.\n\x0cMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x17ListClusterLogsResponse\x12:\n\x04logs\x18\x01 \x03(\x0b\x32,.yandex.cloud.mdb.elasticsearch.v1.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"j\n\x0fStreamLogRecord\x12<\n\x06record\x18\x01 \x01(\x0b\x32,.yandex.cloud.mdb.elasticsearch.v1.LogRecord\x12\x19\n\x11next_record_token\x18\x02 \x01(\t\"\x97\x03\n\x18StreamClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12-\n\tfrom_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x0crecord_token\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x06 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12]\n\x0cservice_type\x18\x07 \x01(\x0e\x32G.yandex.cloud.mdb.elasticsearch.v1.StreamClusterLogsRequest.ServiceType\"J\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x11\n\rELASTICSEARCH\x10\x01\x12\n\n\x06KIBANA\x10\x02\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x17ListClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"k\n\x18ListClusterHostsResponse\x12\x36\n\x05hosts\x18\x01 \x03(\x0b\x32\'.yandex.cloud.mdb.elasticsearch.v1.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"c\n\x12MoveClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x13MoveClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xce\x01\n\x08HostSpec\x12\x19\n\x07zone_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\tsubnet_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x03 \x01(\x08\x12@\n\x04type\x18\x04 \x01(\x0e\x32,.yandex.cloud.mdb.elasticsearch.v1.Host.TypeB\x04\xe8\xc7\x31\x01\x12.\n\nshard_name\x18\x05 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"\xf6\x03\n\x11\x45lasticsearchSpec\x12P\n\tdata_node\x18\x01 \x01(\x0b\x32=.yandex.cloud.mdb.elasticsearch.v1.ElasticsearchSpec.DataNode\x12T\n\x0bmaster_node\x18\x02 \x01(\x0b\x32?.yandex.cloud.mdb.elasticsearch.v1.ElasticsearchSpec.MasterNode\x12\x19\n\x07plugins\x18\x03 \x03(\tB\x08\x8a\xc8\x31\x04<=50\x1a\xce\x01\n\x08\x44\x61taNode\x12w\n\x16\x65lasticsearch_config_7\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.elasticsearch.v1.config.ElasticsearchConfig7H\x00R\x15\x65lasticsearchConfig_7\x12?\n\tresources\x18\x02 \x01(\x0b\x32,.yandex.cloud.mdb.elasticsearch.v1.ResourcesB\x08\n\x06\x63onfig\x1aM\n\nMasterNode\x12?\n\tresources\x18\x01 \x01(\x0b\x32,.yandex.cloud.mdb.elasticsearch.v1.Resources\"\x9e\x01\n\nConfigSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12P\n\x12\x65lasticsearch_spec\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.elasticsearch.v1.ElasticsearchSpec\x12\x0f\n\x07\x65\x64ition\x18\x03 \x01(\t\x12\x1c\n\x0e\x61\x64min_password\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\"\x9e\x01\n\x10\x43onfigSpecUpdate\x12\x0f\n\x07version\x18\x01 \x01(\t\x12P\n\x12\x65lasticsearch_spec\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.elasticsearch.v1.ElasticsearchSpec\x12\x0f\n\x07\x65\x64ition\x18\x03 \x01(\t\x12\x16\n\x0e\x61\x64min_password\x18\x04 \x01(\t\"\x83\x01\n\x16\x41\x64\x64\x43lusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12G\n\nhost_specs\x18\x02 \x03(\x0b\x32+.yandex.cloud.mdb.elasticsearch.v1.HostSpecB\x06\x82\xc8\x31\x02>0\"A\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"b\n\x19\x44\x65leteClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nhost_names\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x02>0\x8a\xc8\x31\x05<=253\"D\n\x1a\x44\x65leteClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\xd2\x02\n\x1cRescheduleMaintenanceRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12m\n\x0freschedule_type\x18\x02 \x01(\x0e\x32N.yandex.cloud.mdb.elasticsearch.v1.RescheduleMaintenanceRequest.RescheduleTypeB\x04\xe8\xc7\x31\x01\x12\x31\n\rdelayed_until\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x0eRescheduleType\x12\x1f\n\x1bRESCHEDULE_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\x19\n\x15NEXT_AVAILABLE_WINDOW\x10\x02\x12\x11\n\rSPECIFIC_TIME\x10\x03\"l\n\x1dRescheduleMaintenanceMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x31\n\rdelayed_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x02\x10\x04\"\x8a\x06\n\x15RestoreClusterRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x91\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x44.yandex.cloud.mdb.elasticsearch.v1.RestoreClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12K\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x36.yandex.cloud.mdb.elasticsearch.v1.Cluster.Environment\x12H\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32-.yandex.cloud.mdb.elasticsearch.v1.ConfigSpecB\x04\xe8\xc7\x31\x01\x12G\n\nhost_specs\x18\t \x03(\x0b\x32+.yandex.cloud.mdb.elasticsearch.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12 \n\nnetwork_id\x18\n \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x0b \x03(\t\x12\x1a\n\x12service_account_id\x18\x0c \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\r \x01(\x08\x12\x1f\n\tfolder_id\x18\x0e \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12I\n\x0f\x65xtension_specs\x18\x0f \x03(\x0b\x32\x30.yandex.cloud.mdb.elasticsearch.v1.ExtensionSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\t\"?\n\x16RestoreClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"8\n\x14\x42\x61\x63kupClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x42\x61\x63kupClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"{\n\x19ListClusterBackupsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"q\n\x1aListClusterBackupsResponse\x12:\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32).yandex.cloud.mdb.elasticsearch.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe4\x1c\n\x0e\x43lusterService\x12\xa0\x01\n\x03Get\x12\x34.yandex.cloud.mdb.elasticsearch.v1.GetClusterRequest\x1a*.yandex.cloud.mdb.elasticsearch.v1.Cluster\"7\x82\xd3\xe4\x93\x02\x31\x12//managed-elasticsearch/v1/clusters/{cluster_id}\x12\xa3\x01\n\x04List\x12\x36.yandex.cloud.mdb.elasticsearch.v1.ListClustersRequest\x1a\x37.yandex.cloud.mdb.elasticsearch.v1.ListClustersResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/managed-elasticsearch/v1/clusters\x12\xb7\x01\n\x06\x43reate\x12\x37.yandex.cloud.mdb.elasticsearch.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"Q\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\'\"\"/managed-elasticsearch/v1/clusters:\x01*\x12\xc4\x01\n\x06Update\x12\x37.yandex.cloud.mdb.elasticsearch.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x34\x32//managed-elasticsearch/v1/clusters/{cluster_id}:\x01*\x12\xcf\x01\n\x06\x44\x65lete\x12\x37.yandex.cloud.mdb.elasticsearch.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x31*//managed-elasticsearch/v1/clusters/{cluster_id}\x12\xc3\x01\n\x04Move\x12\x35.yandex.cloud.mdb.elasticsearch.v1.MoveClusterRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*\x1e\n\x13MoveClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x39\"4/managed-elasticsearch/v1/clusters/{cluster_id}:move:\x01*\x12\xc4\x01\n\x05Start\x12\x36.yandex.cloud.mdb.elasticsearch.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x37\"5/managed-elasticsearch/v1/clusters/{cluster_id}:start\x12\xc0\x01\n\x04Stop\x12\x35.yandex.cloud.mdb.elasticsearch.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x36\"4/managed-elasticsearch/v1/clusters/{cluster_id}:stop\x12\xc8\x01\n\x06\x42\x61\x63kup\x12\x37.yandex.cloud.mdb.elasticsearch.v1.BackupClusterRequest\x1a!.yandex.cloud.operation.Operation\"b\xb2\xd2* \n\x15\x42\x61\x63kupClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x38\"6/managed-elasticsearch/v1/clusters/{cluster_id}:backup\x12\xcb\x01\n\x0bListBackups\x12<.yandex.cloud.mdb.elasticsearch.v1.ListClusterBackupsRequest\x1a=.yandex.cloud.mdb.elasticsearch.v1.ListClusterBackupsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/managed-elasticsearch/v1/clusters/{cluster_id}/backups\x12\xc2\x01\n\x07Restore\x12\x38.yandex.cloud.mdb.elasticsearch.v1.RestoreClusterRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*!\n\x16RestoreClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02/\"*/managed-elasticsearch/v1/clusters:restore:\x01*\x12\xbf\x01\n\x08ListLogs\x12\x39.yandex.cloud.mdb.elasticsearch.v1.ListClusterLogsRequest\x1a:.yandex.cloud.mdb.elasticsearch.v1.ListClusterLogsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/managed-elasticsearch/v1/clusters/{cluster_id}:logs\x12\xc4\x01\n\nStreamLogs\x12;.yandex.cloud.mdb.elasticsearch.v1.StreamClusterLogsRequest\x1a\x32.yandex.cloud.mdb.elasticsearch.v1.StreamLogRecord\"C\x82\xd3\xe4\x93\x02=\x12;/managed-elasticsearch/v1/clusters/{cluster_id}:stream_logs0\x01\x12\xd7\x01\n\x0eListOperations\x12?.yandex.cloud.mdb.elasticsearch.v1.ListClusterOperationsRequest\x1a@.yandex.cloud.mdb.elasticsearch.v1.ListClusterOperationsResponse\"B\x82\xd3\xe4\x93\x02<\x12:/managed-elasticsearch/v1/clusters/{cluster_id}/operations\x12\xc3\x01\n\tListHosts\x12:.yandex.cloud.mdb.elasticsearch.v1.ListClusterHostsRequest\x1a;.yandex.cloud.mdb.elasticsearch.v1.ListClusterHostsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/managed-elasticsearch/v1/clusters/{cluster_id}/hosts\x12\xeb\x01\n\x08\x41\x64\x64Hosts\x12\x39.yandex.cloud.mdb.elasticsearch.v1.AddClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*0\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x46\"A/managed-elasticsearch/v1/clusters/{cluster_id}/hosts:batchCreate:\x01*\x12\xf4\x01\n\x0b\x44\x65leteHosts\x12<.yandex.cloud.mdb.elasticsearch.v1.DeleteClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"\x83\x01\xb2\xd2*3\n\x1a\x44\x65leteClusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x46\"A/managed-elasticsearch/v1/clusters/{cluster_id}/hosts:batchDelete:\x01*\x12\xf9\x01\n\x15RescheduleMaintenance\x12?.yandex.cloud.mdb.elasticsearch.v1.RescheduleMaintenanceRequest\x1a!.yandex.cloud.operation.Operation\"|\xb2\xd2*(\n\x1dRescheduleMaintenanceMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02J\"E/managed-elasticsearch/v1/clusters/{cluster_id}:rescheduleMaintenance:\x01*B|\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.elasticsearch.v1.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearch'
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATECLUSTERREQUEST_LABELSENTRY._options = None
  _CREATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATECLUSTERREQUEST.fields_by_name['name']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _CREATECLUSTERREQUEST.fields_by_name['description']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _CREATECLUSTERREQUEST.fields_by_name['config_spec']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['config_spec']._serialized_options = b'\350\3071\001'
  _CREATECLUSTERREQUEST.fields_by_name['host_specs']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _CREATECLUSTERREQUEST.fields_by_name['network_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATECLUSTERREQUEST_LABELSENTRY._options = None
  _UPDATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATECLUSTERREQUEST.fields_by_name['description']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATECLUSTERREQUEST.fields_by_name['name']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _UPDATECLUSTERREQUEST.fields_by_name['network_id']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['network_id']._serialized_options = b'\212\3101\004<=50'
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LOGRECORD_MESSAGEENTRY._options = None
  _LOGRECORD_MESSAGEENTRY._serialized_options = b'8\001'
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._options = None
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['record_token']._options = None
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['record_token']._serialized_options = b'\212\3101\005<=100'
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['filter']._options = None
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _MOVECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _MOVECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVECLUSTERREQUEST.fields_by_name['destination_folder_id']._options = None
  _MOVECLUSTERREQUEST.fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _HOSTSPEC.fields_by_name['zone_id']._options = None
  _HOSTSPEC.fields_by_name['zone_id']._serialized_options = b'\212\3101\004<=50'
  _HOSTSPEC.fields_by_name['subnet_id']._options = None
  _HOSTSPEC.fields_by_name['subnet_id']._serialized_options = b'\212\3101\004<=50'
  _HOSTSPEC.fields_by_name['type']._options = None
  _HOSTSPEC.fields_by_name['type']._serialized_options = b'\350\3071\001'
  _HOSTSPEC.fields_by_name['shard_name']._options = None
  _HOSTSPEC.fields_by_name['shard_name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _ELASTICSEARCHSPEC.fields_by_name['plugins']._options = None
  _ELASTICSEARCHSPEC.fields_by_name['plugins']._serialized_options = b'\212\3101\004<=50'
  _CONFIGSPEC.fields_by_name['admin_password']._options = None
  _CONFIGSPEC.fields_by_name['admin_password']._serialized_options = b'\350\3071\001'
  _ADDCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _ADDCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDCLUSTERHOSTSREQUEST.fields_by_name['host_specs']._options = None
  _ADDCLUSTERHOSTSREQUEST.fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _DELETECLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _DELETECLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETECLUSTERHOSTSREQUEST.fields_by_name['host_names']._options = None
  _DELETECLUSTERHOSTSREQUEST.fields_by_name['host_names']._serialized_options = b'\202\3101\002>0\212\3101\005<=253'
  _RESCHEDULEMAINTENANCEREQUEST.fields_by_name['cluster_id']._options = None
  _RESCHEDULEMAINTENANCEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESCHEDULEMAINTENANCEREQUEST.fields_by_name['reschedule_type']._options = None
  _RESCHEDULEMAINTENANCEREQUEST.fields_by_name['reschedule_type']._serialized_options = b'\350\3071\001'
  _RESTORECLUSTERREQUEST_LABELSENTRY._options = None
  _RESTORECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _RESTORECLUSTERREQUEST.fields_by_name['backup_id']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _RESTORECLUSTERREQUEST.fields_by_name['name']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _RESTORECLUSTERREQUEST.fields_by_name['description']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _RESTORECLUSTERREQUEST.fields_by_name['labels']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _RESTORECLUSTERREQUEST.fields_by_name['config_spec']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['config_spec']._serialized_options = b'\350\3071\001'
  _RESTORECLUSTERREQUEST.fields_by_name['host_specs']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _RESTORECLUSTERREQUEST.fields_by_name['network_id']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESTORECLUSTERREQUEST.fields_by_name['folder_id']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BACKUPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _BACKUPCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CLUSTERSERVICE.methods_by_name['Get']._options = None
  _CLUSTERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0021\022//managed-elasticsearch/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['List']._options = None
  _CLUSTERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002$\022\"/managed-elasticsearch/v1/clusters'
  _CLUSTERSERVICE.methods_by_name['Create']._options = None
  _CLUSTERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002\'\"\"/managed-elasticsearch/v1/clusters:\001*'
  _CLUSTERSERVICE.methods_by_name['Update']._options = None
  _CLUSTERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\00242//managed-elasticsearch/v1/clusters/{cluster_id}:\001*'
  _CLUSTERSERVICE.methods_by_name['Delete']._options = None
  _CLUSTERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\0021*//managed-elasticsearch/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['Move']._options = None
  _CLUSTERSERVICE.methods_by_name['Move']._serialized_options = b'\262\322*\036\n\023MoveClusterMetadata\022\007Cluster\202\323\344\223\0029\"4/managed-elasticsearch/v1/clusters/{cluster_id}:move:\001*'
  _CLUSTERSERVICE.methods_by_name['Start']._options = None
  _CLUSTERSERVICE.methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\0027\"5/managed-elasticsearch/v1/clusters/{cluster_id}:start'
  _CLUSTERSERVICE.methods_by_name['Stop']._options = None
  _CLUSTERSERVICE.methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\0026\"4/managed-elasticsearch/v1/clusters/{cluster_id}:stop'
  _CLUSTERSERVICE.methods_by_name['Backup']._options = None
  _CLUSTERSERVICE.methods_by_name['Backup']._serialized_options = b'\262\322* \n\025BackupClusterMetadata\022\007Cluster\202\323\344\223\0028\"6/managed-elasticsearch/v1/clusters/{cluster_id}:backup'
  _CLUSTERSERVICE.methods_by_name['ListBackups']._options = None
  _CLUSTERSERVICE.methods_by_name['ListBackups']._serialized_options = b'\202\323\344\223\0029\0227/managed-elasticsearch/v1/clusters/{cluster_id}/backups'
  _CLUSTERSERVICE.methods_by_name['Restore']._options = None
  _CLUSTERSERVICE.methods_by_name['Restore']._serialized_options = b'\262\322*!\n\026RestoreClusterMetadata\022\007Cluster\202\323\344\223\002/\"*/managed-elasticsearch/v1/clusters:restore:\001*'
  _CLUSTERSERVICE.methods_by_name['ListLogs']._options = None
  _CLUSTERSERVICE.methods_by_name['ListLogs']._serialized_options = b'\202\323\344\223\0026\0224/managed-elasticsearch/v1/clusters/{cluster_id}:logs'
  _CLUSTERSERVICE.methods_by_name['StreamLogs']._options = None
  _CLUSTERSERVICE.methods_by_name['StreamLogs']._serialized_options = b'\202\323\344\223\002=\022;/managed-elasticsearch/v1/clusters/{cluster_id}:stream_logs'
  _CLUSTERSERVICE.methods_by_name['ListOperations']._options = None
  _CLUSTERSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002<\022:/managed-elasticsearch/v1/clusters/{cluster_id}/operations'
  _CLUSTERSERVICE.methods_by_name['ListHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['ListHosts']._serialized_options = b'\202\323\344\223\0027\0225/managed-elasticsearch/v1/clusters/{cluster_id}/hosts'
  _CLUSTERSERVICE.methods_by_name['AddHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['AddHosts']._serialized_options = b'\262\322*0\n\027AddClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002F\"A/managed-elasticsearch/v1/clusters/{cluster_id}/hosts:batchCreate:\001*'
  _CLUSTERSERVICE.methods_by_name['DeleteHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['DeleteHosts']._serialized_options = b'\262\322*3\n\032DeleteClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002F\"A/managed-elasticsearch/v1/clusters/{cluster_id}/hosts:batchDelete:\001*'
  _CLUSTERSERVICE.methods_by_name['RescheduleMaintenance']._options = None
  _CLUSTERSERVICE.methods_by_name['RescheduleMaintenance']._serialized_options = b'\262\322*(\n\035RescheduleMaintenanceMetadata\022\007Cluster\202\323\344\223\002J\"E/managed-elasticsearch/v1/clusters/{cluster_id}:rescheduleMaintenance:\001*'
  _globals['_GETCLUSTERREQUEST']._serialized_start=605
  _globals['_GETCLUSTERREQUEST']._serialized_end=658
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=661
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=805
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=807
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=916
  _globals['_CREATECLUSTERREQUEST']._serialized_start=919
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1817
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1766
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1811
  _globals['_CREATECLUSTERMETADATA']._serialized_start=1819
  _globals['_CREATECLUSTERMETADATA']._serialized_end=1862
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=1865
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2509
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1766
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1811
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=2511
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=2554
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2556
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2612
  _globals['_DELETECLUSTERMETADATA']._serialized_start=2614
  _globals['_DELETECLUSTERMETADATA']._serialized_end=2657
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_start=2660
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_end=3124
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=3050
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=3124
  _globals['_LOGRECORD']._serialized_start=3127
  _globals['_LOGRECORD']._serialized_end=3309
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_start=3263
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_end=3309
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_start=3311
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_end=3421
  _globals['_STREAMLOGRECORD']._serialized_start=3423
  _globals['_STREAMLOGRECORD']._serialized_end=3529
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_start=3532
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_end=3939
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=3050
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=3124
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=3941
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=4067
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=4069
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=4180
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_start=4182
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_end=4303
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_start=4305
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_end=4412
  _globals['_MOVECLUSTERREQUEST']._serialized_start=4414
  _globals['_MOVECLUSTERREQUEST']._serialized_end=4513
  _globals['_MOVECLUSTERMETADATA']._serialized_start=4515
  _globals['_MOVECLUSTERMETADATA']._serialized_end=4613
  _globals['_STARTCLUSTERREQUEST']._serialized_start=4615
  _globals['_STARTCLUSTERREQUEST']._serialized_end=4670
  _globals['_STARTCLUSTERMETADATA']._serialized_start=4672
  _globals['_STARTCLUSTERMETADATA']._serialized_end=4714
  _globals['_STOPCLUSTERREQUEST']._serialized_start=4716
  _globals['_STOPCLUSTERREQUEST']._serialized_end=4770
  _globals['_STOPCLUSTERMETADATA']._serialized_start=4772
  _globals['_STOPCLUSTERMETADATA']._serialized_end=4813
  _globals['_HOSTSPEC']._serialized_start=4816
  _globals['_HOSTSPEC']._serialized_end=5022
  _globals['_ELASTICSEARCHSPEC']._serialized_start=5025
  _globals['_ELASTICSEARCHSPEC']._serialized_end=5527
  _globals['_ELASTICSEARCHSPEC_DATANODE']._serialized_start=5242
  _globals['_ELASTICSEARCHSPEC_DATANODE']._serialized_end=5448
  _globals['_ELASTICSEARCHSPEC_MASTERNODE']._serialized_start=5450
  _globals['_ELASTICSEARCHSPEC_MASTERNODE']._serialized_end=5527
  _globals['_CONFIGSPEC']._serialized_start=5530
  _globals['_CONFIGSPEC']._serialized_end=5688
  _globals['_CONFIGSPECUPDATE']._serialized_start=5691
  _globals['_CONFIGSPECUPDATE']._serialized_end=5849
  _globals['_ADDCLUSTERHOSTSREQUEST']._serialized_start=5852
  _globals['_ADDCLUSTERHOSTSREQUEST']._serialized_end=5983
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_start=5985
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_end=6050
  _globals['_DELETECLUSTERHOSTSREQUEST']._serialized_start=6052
  _globals['_DELETECLUSTERHOSTSREQUEST']._serialized_end=6150
  _globals['_DELETECLUSTERHOSTSMETADATA']._serialized_start=6152
  _globals['_DELETECLUSTERHOSTSMETADATA']._serialized_end=6220
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_start=6223
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_end=6561
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_start=6451
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_end=6561
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_start=6563
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_end=6671
  _globals['_RESTORECLUSTERREQUEST']._serialized_start=6674
  _globals['_RESTORECLUSTERREQUEST']._serialized_end=7452
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_start=1766
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_end=1811
  _globals['_RESTORECLUSTERMETADATA']._serialized_start=7454
  _globals['_RESTORECLUSTERMETADATA']._serialized_end=7517
  _globals['_BACKUPCLUSTERREQUEST']._serialized_start=7519
  _globals['_BACKUPCLUSTERREQUEST']._serialized_end=7575
  _globals['_BACKUPCLUSTERMETADATA']._serialized_start=7577
  _globals['_BACKUPCLUSTERMETADATA']._serialized_end=7620
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_start=7622
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_end=7745
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_start=7747
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_end=7860
  _globals['_CLUSTERSERVICE']._serialized_start=7863
  _globals['_CLUSTERSERVICE']._serialized_end=11547
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/lockbox/v1/secret_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.lockbox.v1 import secret_pb2 as yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/lockbox/v1/secret_service.proto\x12\x17yandex.cloud.lockbox.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a$yandex/cloud/lockbox/v1/secret.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\x98\x01\n\x12PayloadEntryChange\x12\x31\n\x03key\x18\x01 \x01(\tB$\xe8\xc7\x31\x01\xf2\xc7\x31\x13[-_./\\\\@0-9a-zA-Z]+\x8a\xc8\x31\x05<=256\x12!\n\ntext_value\x18\x02 \x01(\tB\x0b\x8a\xc8\x31\x07<=65536H\x00\x12#\n\x0c\x62inary_value\x18\x03 \x01(\x0c\x42\x0b\x8a\xc8\x31\x07<=65536H\x00\x42\x07\n\x05value\"3\n\x10GetSecretRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"s\n\x12ListSecretsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"`\n\x13ListSecretsResponse\x12\x30\n\x07secrets\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.lockbox.v1.Secret\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xdc\x04\n\x13\x43reateSecretRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x04name\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x85\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x38.yandex.cloud.lockbox.v1.CreateSecretRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x1c\n\nkms_key_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12&\n\x13version_description\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12V\n\x17version_payload_entries\x18\x07 \x03(\x0b\x32+.yandex.cloud.lockbox.v1.PayloadEntryChangeB\x08\x82\xc8\x31\x04<=32\x12\x1b\n\x13\x64\x65letion_protection\x18\x08 \x01(\x08\x12_\n\x1epassword_payload_specification\x18\t \x01(\x0b\x32\x35.yandex.cloud.lockbox.v1.PasswordPayloadSpecificationH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x17\n\x15payload_specification\"=\n\x14\x43reateSecretMetadata\x12\x11\n\tsecret_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\"\xf5\x03\n\x13UpdateSecretRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x17\n\x04name\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x85\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x38.yandex.cloud.lockbox.v1.UpdateSecretRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x12_\n\x1epassword_payload_specification\x18\x07 \x01(\x0b\x32\x35.yandex.cloud.lockbox.v1.PasswordPayloadSpecificationH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x17\n\x15payload_specification\"7\n\x14UpdateSecretMetadata\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"6\n\x13\x44\x65leteSecretRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x14\x44\x65leteSecretMetadata\x12\x11\n\tsecret_id\x18\x01 \x01(\t\"8\n\x15\x41\x63tivateSecretRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x16\x41\x63tivateSecretMetadata\x12\x11\n\tsecret_id\x18\x01 \x01(\t\":\n\x17\x44\x65\x61\x63tivateSecretRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x18\x44\x65\x61\x63tivateSecretMetadata\x12\x11\n\tsecret_id\x18\x01 \x01(\t\"\xc8\x01\n\x11\x41\x64\x64VersionRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\x0b\x64\x65scription\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12N\n\x0fpayload_entries\x18\x03 \x03(\x0b\x32+.yandex.cloud.lockbox.v1.PayloadEntryChangeB\x08\x82\xc8\x31\x04<=32\x12!\n\x0f\x62\x61se_version_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50\";\n\x12\x41\x64\x64VersionMetadata\x12\x11\n\tsecret_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\"t\n\x13ListVersionsRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"c\n\x14ListVersionsResponse\x12\x32\n\x08versions\x18\x01 \x03(\x0b\x32 .yandex.cloud.lockbox.v1.Version\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x99\x01\n!ScheduleVersionDestructionRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nversion_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x31\n\x0epending_period\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"{\n\"ScheduleVersionDestructionMetadata\x12\x11\n\tsecret_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12.\n\ndestroy_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"d\n\x1f\x43\x61ncelVersionDestructionRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nversion_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"I\n CancelVersionDestructionMetadata\x12\x11\n\tsecret_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\"|\n\x1bListSecretOperationsRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x1cListSecretOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe9\x15\n\rSecretService\x12z\n\x03Get\x12).yandex.cloud.lockbox.v1.GetSecretRequest\x1a\x1f.yandex.cloud.lockbox.v1.Secret\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/lockbox/v1/secrets/{secret_id}\x12~\n\x04List\x12+.yandex.cloud.lockbox.v1.ListSecretsRequest\x1a,.yandex.cloud.lockbox.v1.ListSecretsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/lockbox/v1/secrets\x12\x9b\x01\n\x06\x43reate\x12,.yandex.cloud.lockbox.v1.CreateSecretRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*\x1e\n\x14\x43reateSecretMetadata\x12\x06Secret\x82\xd3\xe4\x93\x02\x18\"\x13/lockbox/v1/secrets:\x01*\x12\xa7\x01\n\x06Update\x12,.yandex.cloud.lockbox.v1.UpdateSecretRequest\x1a!.yandex.cloud.operation.Operation\"L\xb2\xd2*\x1e\n\x14UpdateSecretMetadata\x12\x06Secret\x82\xd3\xe4\x93\x02$2\x1f/lockbox/v1/secrets/{secret_id}:\x01*\x12\xa4\x01\n\x06\x44\x65lete\x12,.yandex.cloud.lockbox.v1.DeleteSecretRequest\x1a!.yandex.cloud.operation.Operation\"I\xb2\xd2*\x1e\n\x14\x44\x65leteSecretMetadata\x12\x06Secret\x82\xd3\xe4\x93\x02!*\x1f/lockbox/v1/secrets/{secret_id}\x12\xb3\x01\n\x08\x41\x63tivate\x12..yandex.cloud.lockbox.v1.ActivateSecretRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2* \n\x16\x41\x63tivateSecretMetadata\x12\x06Secret\x82\xd3\xe4\x93\x02*\"(/lockbox/v1/secrets/{secret_id}:activate\x12\xbb\x01\n\nDeactivate\x12\x30.yandex.cloud.lockbox.v1.DeactivateSecretRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*\"\n\x18\x44\x65\x61\x63tivateSecretMetadata\x12\x06Secret\x82\xd3\xe4\x93\x02,\"*/lockbox/v1/secrets/{secret_id}:deactivate\x12\x9d\x01\n\x0cListVersions\x12,.yandex.cloud.lockbox.v1.ListVersionsRequest\x1a-.yandex.cloud.lockbox.v1.ListVersionsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/lockbox/v1/secrets/{secret_id}/versions\x12\xb3\x01\n\nAddVersion\x12*.yandex.cloud.lockbox.v1.AddVersionRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*\x1d\n\x12\x41\x64\x64VersionMetadata\x12\x07Version\x82\xd3\xe4\x93\x02/\"*/lockbox/v1/secrets/{secret_id}:addVersion:\x01*\x12\xf3\x01\n\x1aScheduleVersionDestruction\x12:.yandex.cloud.lockbox.v1.ScheduleVersionDestructionRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*-\n\"ScheduleVersionDestructionMetadata\x12\x07Version\x82\xd3\xe4\x93\x02?\":/lockbox/v1/secrets/{secret_id}:scheduleVersionDestruction:\x01*\x12\xeb\x01\n\x18\x43\x61ncelVersionDestruction\x12\x38.yandex.cloud.lockbox.v1.CancelVersionDestructionRequest\x1a!.yandex.cloud.operation.Operation\"r\xb2\xd2*+\n CancelVersionDestructionMetadata\x12\x07Version\x82\xd3\xe4\x93\x02=\"8/lockbox/v1/secrets/{secret_id}:cancelVersionDestruction:\x01*\x12\xb1\x01\n\x0eListOperations\x12\x34.yandex.cloud.lockbox.v1.ListSecretOperationsRequest\x1a\x35.yandex.cloud.lockbox.v1.ListSecretOperationsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/lockbox/v1/secrets/{secret_id}/operations\x12\xb3\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/lockbox/v1/secrets/{resource_id}:listAccessBindings\x12\xe2\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x38\"3/lockbox/v1/secrets/{resource_id}:setAccessBindings:\x01*\x12\xef\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x81\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02;\"6/lockbox/v1/secrets/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockboxb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.lockbox.v1.secret_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockbox'
  _PAYLOADENTRYCHANGE.fields_by_name['key']._options = None
  _PAYLOADENTRYCHANGE.fields_by_name['key']._serialized_options = b'\350\3071\001\362\3071\023[-_./\\\\@0-9a-zA-Z]+\212\3101\005<=256'
  _PAYLOADENTRYCHANGE.fields_by_name['text_value']._options = None
  _PAYLOADENTRYCHANGE.fields_by_name['text_value']._serialized_options = b'\212\3101\007<=65536'
  _PAYLOADENTRYCHANGE.fields_by_name['binary_value']._options = None
  _PAYLOADENTRYCHANGE.fields_by_name['binary_value']._serialized_options = b'\212\3101\007<=65536'
  _GETSECRETREQUEST.fields_by_name['secret_id']._options = None
  _GETSECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSECRETSREQUEST.fields_by_name['folder_id']._options = None
  _LISTSECRETSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSECRETSREQUEST.fields_by_name['page_size']._options = None
  _LISTSECRETSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTSECRETSREQUEST.fields_by_name['page_token']._options = None
  _LISTSECRETSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATESECRETREQUEST_LABELSENTRY._options = None
  _CREATESECRETREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATESECRETREQUEST.fields_by_name['folder_id']._options = None
  _CREATESECRETREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESECRETREQUEST.fields_by_name['name']._options = None
  _CREATESECRETREQUEST.fields_by_name['name']._serialized_options = b'\212\3101\005<=100'
  _CREATESECRETREQUEST.fields_by_name['description']._options = None
  _CREATESECRETREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _CREATESECRETREQUEST.fields_by_name['labels']._options = None
  _CREATESECRETREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _CREATESECRETREQUEST.fields_by_name['kms_key_id']._options = None
  _CREATESECRETREQUEST.fields_by_name['kms_key_id']._serialized_options = b'\212\3101\004<=50'
  _CREATESECRETREQUEST.fields_by_name['version_description']._options = None
  _CREATESECRETREQUEST.fields_by_name['version_description']._serialized_options = b'\212\3101\005<=256'
  _CREATESECRETREQUEST.fields_by_name['version_payload_entries']._options = None
  _CREATESECRETREQUEST.fields_by_name['version_payload_entries']._serialized_options = b'\202\3101\004<=32'
  _UPDATESECRETREQUEST_LABELSENTRY._options = None
  _UPDATESECRETREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATESECRETREQUEST.fields_by_name['secret_id']._options = None
  _UPDATESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATESECRETREQUEST.fields_by_name['update_mask']._options = None
  _UPDATESECRETREQUEST.fields_by_name['update_mask']._serialized_options = b'\350\3071\001'
  _UPDATESECRETREQUEST.fields_by_name['name']._options = None
  _UPDATESECRETREQUEST.fields_by_name['name']._serialized_options = b'\212\3101\005<=100'
  _UPDATESECRETREQUEST.fields_by_name['description']._options = None
  _UPDATESECRETREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _UPDATESECRETREQUEST.fields_by_name['labels']._options = None
  _UPDATESECRETREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _UPDATESECRETMETADATA.fields_by_name['secret_id']._options = None
  _UPDATESECRETMETADATA.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETESECRETREQUEST.fields_by_name['secret_id']._options = None
  _DELETESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ACTIVATESECRETREQUEST.fields_by_name['secret_id']._options = None
  _ACTIVATESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DEACTIVATESECRETREQUEST.fields_by_name['secret_id']._options = None
  _DEACTIVATESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDVERSIONREQUEST.fields_by_name['secret_id']._options = None
  _ADDVERSIONREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDVERSIONREQUEST.fields_by_name['description']._options = None
  _ADDVERSIONREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _ADDVERSIONREQUEST.fields_by_name['payload_entries']._options = None
  _ADDVERSIONREQUEST.fields_by_name['payload_entries']._serialized_options = b'\202\3101\004<=32'
  _ADDVERSIONREQUEST.fields_by_name['base_version_id']._options = None
  _ADDVERSIONREQUEST.fields_by_name['base_version_id']._serialized_options = b'\212\3101\004<=50'
  _LISTVERSIONSREQUEST.fields_by_name['secret_id']._options = None
  _LISTVERSIONSREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTVERSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTVERSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTVERSIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTVERSIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _SCHEDULEVERSIONDESTRUCTIONREQUEST.fields_by_name['secret_id']._options = None
  _SCHEDULEVERSIONDESTRUCTIONREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _SCHEDULEVERSIONDESTRUCTIONREQUEST.fields_by_name['version_id']._options = None
  _SCHEDULEVERSIONDESTRUCTIONREQUEST.fields_by_name['version_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CANCELVERSIONDESTRUCTIONREQUEST.fields_by_name['secret_id']._options = None
  _CANCELVERSIONDESTRUCTIONREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CANCELVERSIONDESTRUCTIONREQUEST.fields_by_name['version_id']._options = None
  _CANCELVERSIONDESTRUCTIONREQUEST.fields_by_name['version_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSECRETOPERATIONSREQUEST.fields_by_name['secret_id']._options = None
  _LISTSECRETOPERATIONSREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSECRETOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTSECRETOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTSECRETOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTSECRETOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _SECRETSERVICE.methods_by_name['Get']._options = None
  _SECRETSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/lockbox/v1/secrets/{secret_id}'
  _SECRETSERVICE.methods_by_name['List']._options = None
  _SECRETSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\025\022\023/lockbox/v1/secrets'
  _SECRETSERVICE.methods_by_name['Create']._options = None
  _SECRETSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreateSecretMetadata\022\006Secret\202\323\344\223\002\030\"\023/lockbox/v1/secrets:\001*'
  _SECRETSERVICE.methods_by_name['Update']._options = None
  _SECRETSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdateSecretMetadata\022\006Secret\202\323\344\223\002$2\037/lockbox/v1/secrets/{secret_id}:\001*'
  _SECRETSERVICE.methods_by_name['Delete']._options = None
  _SECRETSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*\036\n\024DeleteSecretMetadata\022\006Secret\202\323\344\223\002!*\037/lockbox/v1/secrets/{secret_id}'
  _SECRETSERVICE.methods_by_name['Activate']._options = None
  _SECRETSERVICE.methods_by_name['Activate']._serialized_options = b'\262\322* \n\026ActivateSecretMetadata\022\006Secret\202\323\344\223\002*\"(/lockbox/v1/secrets/{secret_id}:activate'
  _SECRETSERVICE.methods_by_name['Deactivate']._options = None
  _SECRETSERVICE.methods_by_name['Deactivate']._serialized_options = b'\262\322*\"\n\030DeactivateSecretMetadata\022\006Secret\202\323\344\223\002,\"*/lockbox/v1/secrets/{secret_id}:deactivate'
  _SECRETSERVICE.methods_by_name['ListVersions']._options = None
  _SECRETSERVICE.methods_by_name['ListVersions']._serialized_options = b'\202\323\344\223\002*\022(/lockbox/v1/secrets/{secret_id}/versions'
  _SECRETSERVICE.methods_by_name['AddVersion']._options = None
  _SECRETSERVICE.methods_by_name['AddVersion']._serialized_options = b'\262\322*\035\n\022AddVersionMetadata\022\007Version\202\323\344\223\002/\"*/lockbox/v1/secrets/{secret_id}:addVersion:\001*'
  _SECRETSERVICE.methods_by_name['ScheduleVersionDestruction']._options = None
  _SECRETSERVICE.methods_by_name['ScheduleVersionDestruction']._serialized_options = b'\262\322*-\n\"ScheduleVersionDestructionMetadata\022\007Version\202\323\344\223\002?\":/lockbox/v1/secrets/{secret_id}:scheduleVersionDestruction:\001*'
  _SECRETSERVICE.methods_by_name['CancelVersionDestruction']._options = None
  _SECRETSERVICE.methods_by_name['CancelVersionDestruction']._serialized_options = b'\262\322*+\n CancelVersionDestructionMetadata\022\007Version\202\323\344\223\002=\"8/lockbox/v1/secrets/{secret_id}:cancelVersionDestruction:\001*'
  _SECRETSERVICE.methods_by_name['ListOperations']._options = None
  _SECRETSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002,\022*/lockbox/v1/secrets/{secret_id}/operations'
  _SECRETSERVICE.methods_by_name['ListAccessBindings']._options = None
  _SECRETSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0026\0224/lockbox/v1/secrets/{resource_id}:listAccessBindings'
  _SECRETSERVICE.methods_by_name['SetAccessBindings']._options = None
  _SECRETSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\0028\"3/lockbox/v1/secrets/{resource_id}:setAccessBindings:\001*'
  _SECRETSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _SECRETSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002;\"6/lockbox/v1/secrets/{resource_id}:updateAccessBindings:\001*'
  _globals['_PAYLOADENTRYCHANGE']._serialized_start=380
  _globals['_PAYLOADENTRYCHANGE']._serialized_end=532
  _globals['_GETSECRETREQUEST']._serialized_start=534
  _globals['_GETSECRETREQUEST']._serialized_end=585
  _globals['_LISTSECRETSREQUEST']._serialized_start=587
  _globals['_LISTSECRETSREQUEST']._serialized_end=702
  _globals['_LISTSECRETSRESPONSE']._serialized_start=704
  _globals['_LISTSECRETSRESPONSE']._serialized_end=800
  _globals['_CREATESECRETREQUEST']._serialized_start=803
  _globals['_CREATESECRETREQUEST']._serialized_end=1407
  _globals['_CREATESECRETREQUEST_LABELSENTRY']._serialized_start=1337
  _globals['_CREATESECRETREQUEST_LABELSENTRY']._serialized_end=1382
  _globals['_CREATESECRETMETADATA']._serialized_start=1409
  _globals['_CREATESECRETMETADATA']._serialized_end=1470
  _globals['_UPDATESECRETREQUEST']._serialized_start=1473
  _globals['_UPDATESECRETREQUEST']._serialized_end=1974
  _globals['_UPDATESECRETREQUEST_LABELSENTRY']._serialized_start=1337
  _globals['_UPDATESECRETREQUEST_LABELSENTRY']._serialized_end=1382
  _globals['_UPDATESECRETMETADATA']._serialized_start=1976
  _globals['_UPDATESECRETMETADATA']._serialized_end=2031
  _globals['_DELETESECRETREQUEST']._serialized_start=2033
  _globals['_DELETESECRETREQUEST']._serialized_end=2087
  _globals['_DELETESECRETMETADATA']._serialized_start=2089
  _globals['_DELETESECRETMETADATA']._serialized_end=2130
  _globals['_ACTIVATESECRETREQUEST']._serialized_start=2132
  _globals['_ACTIVATESECRETREQUEST']._serialized_end=2188
  _globals['_ACTIVATESECRETMETADATA']._serialized_start=2190
  _globals['_ACTIVATESECRETMETADATA']._serialized_end=2233
  _globals['_DEACTIVATESECRETREQUEST']._serialized_start=2235
  _globals['_DEACTIVATESECRETREQUEST']._serialized_end=2293
  _globals['_DEACTIVATESECRETMETADATA']._serialized_start=2295
  _globals['_DEACTIVATESECRETMETADATA']._serialized_end=2340
  _globals['_ADDVERSIONREQUEST']._serialized_start=2343
  _globals['_ADDVERSIONREQUEST']._serialized_end=2543
  _globals['_ADDVERSIONMETADATA']._serialized_start=2545
  _globals['_ADDVERSIONMETADATA']._serialized_end=2604
  _globals['_LISTVERSIONSREQUEST']._serialized_start=2606
  _globals['_LISTVERSIONSREQUEST']._serialized_end=2722
  _globals['_LISTVERSIONSRESPONSE']._serialized_start=2724
  _globals['_LISTVERSIONSRESPONSE']._serialized_end=2823
  _globals['_SCHEDULEVERSIONDESTRUCTIONREQUEST']._serialized_start=2826
  _globals['_SCHEDULEVERSIONDESTRUCTIONREQUEST']._serialized_end=2979
  _globals['_SCHEDULEVERSIONDESTRUCTIONMETADATA']._serialized_start=2981
  _globals['_SCHEDULEVERSIONDESTRUCTIONMETADATA']._serialized_end=3104
  _globals['_CANCELVERSIONDESTRUCTIONREQUEST']._serialized_start=3106
  _globals['_CANCELVERSIONDESTRUCTIONREQUEST']._serialized_end=3206
  _globals['_CANCELVERSIONDESTRUCTIONMETADATA']._serialized_start=3208
  _globals['_CANCELVERSIONDESTRUCTIONMETADATA']._serialized_end=3281
  _globals['_LISTSECRETOPERATIONSREQUEST']._serialized_start=3283
  _globals['_LISTSECRETOPERATIONSREQUEST']._serialized_end=3407
  _globals['_LISTSECRETOPERATIONSRESPONSE']._serialized_start=3409
  _globals['_LISTSECRETOPERATIONSRESPONSE']._serialized_end=3519
  _globals['_SECRETSERVICE']._serialized_start=3522
  _globals['_SECRETSERVICE']._serialized_end=6315
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RouteTable(google.protobuf.message.Message):
    """A RouteTable resource. For more information, see [Static Routes](/docs/vpc/concepts/routing)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    STATIC_ROUTES_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the route table."""
    folder_id: builtins.str
    """ID of the folder that the route table belongs to."""
    name: builtins.str
    """Name of the route table. 
    The name must be unique within the folder. 
    Value must match the regular expression `|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?`.
    """
    description: builtins.str
    """Optional description of the route table. 0-256 characters long."""
    network_id: builtins.str
    """ID of the network the route table belongs to."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels, `key:value` pairs.
        No more than 64 per resource. 
        The string length in characters for each key must be 1-63.
        Each value must match the regular expression `[-_0-9a-z]*`. 
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    @property
    def static_routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StaticRoute]:
        """List of static routes."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network_id: builtins.str = ...,
        static_routes: collections.abc.Iterable[global___StaticRoute] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "network_id", b"network_id", "static_routes", b"static_routes"]) -> None: ...

global___RouteTable = RouteTable

@typing.final
class StaticRoute(google.protobuf.message.Message):
    """A StaticRoute resource. For more information, see [Static Routes](/docs/vpc/concepts/routing)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESTINATION_PREFIX_FIELD_NUMBER: builtins.int
    NEXT_HOP_ADDRESS_FIELD_NUMBER: builtins.int
    GATEWAY_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    destination_prefix: builtins.str
    """Destination subnet in CIDR notation"""
    next_hop_address: builtins.str
    """Next hop IP address"""
    gateway_id: builtins.str
    """Next hop gateway id"""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs. Maximum of 64 per resource."""

    def __init__(
        self,
        *,
        destination_prefix: builtins.str = ...,
        next_hop_address: builtins.str = ...,
        gateway_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "destination_prefix", b"destination_prefix", "gateway_id", b"gateway_id", "next_hop", b"next_hop", "next_hop_address", b"next_hop_address"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination", b"destination", "destination_prefix", b"destination_prefix", "gateway_id", b"gateway_id", "labels", b"labels", "next_hop", b"next_hop", "next_hop_address", b"next_hop_address"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["destination_prefix"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["next_hop", b"next_hop"]) -> typing.Literal["next_hop_address", "gateway_id"] | None: ...

global___StaticRoute = StaticRoute



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.assistants.v1.assistant_pb2
import yandex.cloud.ai.assistants.v1.assistant_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class AssistantServiceStub:
    """AssistantService provides operations for managing assistants."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.CreateAssistantRequest,
        yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant,
    ]
    """Create a new assistant."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.GetAssistantRequest,
        yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant,
    ]
    """Retrieve details of a specific assistant by its ID."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.UpdateAssistantRequest,
        yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant,
    ]
    """Update an existing assistant."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.DeleteAssistantRequest,
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.DeleteAssistantResponse,
    ]
    """Delete an assistant by its ID."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.ListAssistantsRequest,
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.ListAssistantsResponse,
    ]
    """List assistants in a specific folder."""

    ListVersions: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.ListAssistantVersionsRequest,
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.ListAssistantVersionsResponse,
    ]
    """Lists all versions of a specific assistant."""

class AssistantServiceAsyncStub:
    """AssistantService provides operations for managing assistants."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.CreateAssistantRequest,
        yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant,
    ]
    """Create a new assistant."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.GetAssistantRequest,
        yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant,
    ]
    """Retrieve details of a specific assistant by its ID."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.UpdateAssistantRequest,
        yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant,
    ]
    """Update an existing assistant."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.DeleteAssistantRequest,
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.DeleteAssistantResponse,
    ]
    """Delete an assistant by its ID."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.ListAssistantsRequest,
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.ListAssistantsResponse,
    ]
    """List assistants in a specific folder."""

    ListVersions: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.ListAssistantVersionsRequest,
        yandex.cloud.ai.assistants.v1.assistant_service_pb2.ListAssistantVersionsResponse,
    ]
    """Lists all versions of a specific assistant."""

class AssistantServiceServicer(metaclass=abc.ABCMeta):
    """AssistantService provides operations for managing assistants."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.ai.assistants.v1.assistant_service_pb2.CreateAssistantRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant]]:
        """Create a new assistant."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.ai.assistants.v1.assistant_service_pb2.GetAssistantRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant]]:
        """Retrieve details of a specific assistant by its ID."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.ai.assistants.v1.assistant_service_pb2.UpdateAssistantRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.assistant_pb2.Assistant]]:
        """Update an existing assistant."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.ai.assistants.v1.assistant_service_pb2.DeleteAssistantRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.assistant_service_pb2.DeleteAssistantResponse, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.assistant_service_pb2.DeleteAssistantResponse]]:
        """Delete an assistant by its ID."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.ai.assistants.v1.assistant_service_pb2.ListAssistantsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.assistant_service_pb2.ListAssistantsResponse, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.assistant_service_pb2.ListAssistantsResponse]]:
        """List assistants in a specific folder."""

    @abc.abstractmethod
    def ListVersions(
        self,
        request: yandex.cloud.ai.assistants.v1.assistant_service_pb2.ListAssistantVersionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.assistant_service_pb2.ListAssistantVersionsResponse, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.assistant_service_pb2.ListAssistantVersionsResponse]]:
        """Lists all versions of a specific assistant."""

def add_AssistantServiceServicer_to_server(servicer: AssistantServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"yandex/cloud/iam/v1/resource.proto\x12\x13yandex.cloud.iam.v1\x1a\x1dyandex/cloud/validation.proto\"@\n\x08Resource\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x04type\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64BV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.resource_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _RESOURCE.fields_by_name['id']._options = None
  _RESOURCE.fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESOURCE.fields_by_name['type']._options = None
  _RESOURCE.fields_by_name['type']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _globals['_RESOURCE']._serialized_start=90
  _globals['_RESOURCE']._serialized_end=154
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/trail_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/loadtesting/agent/v1/trail_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1cgoogle/api/annotations.proto\"\x94\x01\n\x12\x43reateTrailRequest\x12\x1b\n\x13\x63ompute_instance_id\x18\x01 \x01(\t\x12\x36\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32(.yandex.cloud.loadtesting.agent.v1.Trail\x12\x0e\n\x06job_id\x18\x03 \x01(\t\x12\x19\n\x11\x61gent_instance_id\x18\x04 \x01(\t\"\xfc\x04\n\x05Trail\x12\x0f\n\x07overall\x18\x01 \x01(\x03\x12\x0f\n\x07\x63\x61se_id\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\t\x12\r\n\x05reqps\x18\x04 \x01(\x03\x12\r\n\x05resps\x18\x05 \x01(\x03\x12\x0e\n\x06\x65xpect\x18\x06 \x01(\x01\x12\r\n\x05input\x18\x07 \x01(\x03\x12\x0e\n\x06output\x18\x08 \x01(\x03\x12\x14\n\x0c\x63onnect_time\x18\t \x01(\x01\x12\x11\n\tsend_time\x18\n \x01(\x01\x12\x0f\n\x07latency\x18\x0b \x01(\x01\x12\x14\n\x0creceive_time\x18\x0c \x01(\x01\x12\x0f\n\x07threads\x18\r \x01(\x03\x12\x0b\n\x03q50\x18\x0e \x01(\x01\x12\x0b\n\x03q75\x18\x0f \x01(\x01\x12\x0b\n\x03q80\x18\x10 \x01(\x01\x12\x0b\n\x03q85\x18\x11 \x01(\x01\x12\x0b\n\x03q90\x18\x12 \x01(\x01\x12\x0b\n\x03q95\x18\x13 \x01(\x01\x12\x0b\n\x03q98\x18\x14 \x01(\x01\x12\x0b\n\x03q99\x18\x15 \x01(\x01\x12\x0c\n\x04q100\x18\x16 \x01(\x01\x12\x42\n\nhttp_codes\x18\x17 \x03(\x0b\x32..yandex.cloud.loadtesting.agent.v1.Trail.Codes\x12\x41\n\tnet_codes\x18\x18 \x03(\x0b\x32..yandex.cloud.loadtesting.agent.v1.Trail.Codes\x12J\n\x0etime_intervals\x18\x19 \x03(\x0b\x32\x32.yandex.cloud.loadtesting.agent.v1.Trail.Intervals\x1a$\n\x05\x43odes\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x1a&\n\tIntervals\x12\n\n\x02to\x18\x01 \x01(\x01\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\"5\n\x13\x43reateTrailResponse\x12\x10\n\x08trail_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x03\x32\xb1\x01\n\x0cTrailService\x12\xa0\x01\n\x06\x43reate\x12\x35.yandex.cloud.loadtesting.agent.v1.CreateTrailRequest\x1a\x36.yandex.cloud.loadtesting.agent.v1.CreateTrailResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/loadtesting/agent/v1/trails:\x01*Bt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.agent.v1.trail_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent'
  _TRAILSERVICE.methods_by_name['Create']._options = None
  _TRAILSERVICE.methods_by_name['Create']._serialized_options = b'\202\323\344\223\002!\"\034/loadtesting/agent/v1/trails:\001*'
  _globals['_CREATETRAILREQUEST']._serialized_start=123
  _globals['_CREATETRAILREQUEST']._serialized_end=271
  _globals['_TRAIL']._serialized_start=274
  _globals['_TRAIL']._serialized_end=910
  _globals['_TRAIL_CODES']._serialized_start=834
  _globals['_TRAIL_CODES']._serialized_end=870
  _globals['_TRAIL_INTERVALS']._serialized_start=872
  _globals['_TRAIL_INTERVALS']._serialized_end=910
  _globals['_CREATETRAILRESPONSE']._serialized_start=912
  _globals['_CREATETRAILRESPONSE']._serialized_end=965
  _globals['_TRAILSERVICE']._serialized_start=968
  _globals['_TRAILSERVICE']._serialized_end=1145
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Downsampling(google.protobuf.message.Message):
    """List of available aggregate functions for downsampling."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _GridAggregation:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _GridAggregationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Downsampling._GridAggregation.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        GRID_AGGREGATION_UNSPECIFIED: Downsampling._GridAggregation.ValueType  # 0
        GRID_AGGREGATION_MAX: Downsampling._GridAggregation.ValueType  # 1
        """Max value."""
        GRID_AGGREGATION_MIN: Downsampling._GridAggregation.ValueType  # 2
        """Min value."""
        GRID_AGGREGATION_SUM: Downsampling._GridAggregation.ValueType  # 3
        """Sum of values."""
        GRID_AGGREGATION_AVG: Downsampling._GridAggregation.ValueType  # 4
        """Average value."""
        GRID_AGGREGATION_LAST: Downsampling._GridAggregation.ValueType  # 5
        """Last value."""
        GRID_AGGREGATION_COUNT: Downsampling._GridAggregation.ValueType  # 6
        """Total count of points."""

    class GridAggregation(_GridAggregation, metaclass=_GridAggregationEnumTypeWrapper):
        """List of available aggregate functions for downsampling."""

    GRID_AGGREGATION_UNSPECIFIED: Downsampling.GridAggregation.ValueType  # 0
    GRID_AGGREGATION_MAX: Downsampling.GridAggregation.ValueType  # 1
    """Max value."""
    GRID_AGGREGATION_MIN: Downsampling.GridAggregation.ValueType  # 2
    """Min value."""
    GRID_AGGREGATION_SUM: Downsampling.GridAggregation.ValueType  # 3
    """Sum of values."""
    GRID_AGGREGATION_AVG: Downsampling.GridAggregation.ValueType  # 4
    """Average value."""
    GRID_AGGREGATION_LAST: Downsampling.GridAggregation.ValueType  # 5
    """Last value."""
    GRID_AGGREGATION_COUNT: Downsampling.GridAggregation.ValueType  # 6
    """Total count of points."""

    class _GapFilling:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _GapFillingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Downsampling._GapFilling.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        GAP_FILLING_UNSPECIFIED: Downsampling._GapFilling.ValueType  # 0
        GAP_FILLING_NULL: Downsampling._GapFilling.ValueType  # 1
        """Returns `null` as a metric value and `timestamp` as a time series value."""
        GAP_FILLING_NONE: Downsampling._GapFilling.ValueType  # 2
        """Returns no value and no timestamp."""
        GAP_FILLING_PREVIOUS: Downsampling._GapFilling.ValueType  # 3
        """Returns the value from the previous time interval."""

    class GapFilling(_GapFilling, metaclass=_GapFillingEnumTypeWrapper):
        """List of available gap filling policy for downsampling."""

    GAP_FILLING_UNSPECIFIED: Downsampling.GapFilling.ValueType  # 0
    GAP_FILLING_NULL: Downsampling.GapFilling.ValueType  # 1
    """Returns `null` as a metric value and `timestamp` as a time series value."""
    GAP_FILLING_NONE: Downsampling.GapFilling.ValueType  # 2
    """Returns no value and no timestamp."""
    GAP_FILLING_PREVIOUS: Downsampling.GapFilling.ValueType  # 3
    """Returns the value from the previous time interval."""

    MAX_POINTS_FIELD_NUMBER: builtins.int
    GRID_INTERVAL_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    GRID_AGGREGATION_FIELD_NUMBER: builtins.int
    GAP_FILLING_FIELD_NUMBER: builtins.int
    max_points: builtins.int
    """Maximum number of points to be returned."""
    grid_interval: builtins.int
    """Time interval (grid) for downsampling in milliseconds.
    Points in the specified range are aggregated into one time point.
    """
    disabled: builtins.bool
    """Disable downsampling."""
    grid_aggregation: global___Downsampling.GridAggregation.ValueType
    """Function that is used for downsampling."""
    gap_filling: global___Downsampling.GapFilling.ValueType
    """Parameters for filling gaps in data."""
    def __init__(
        self,
        *,
        max_points: builtins.int = ...,
        grid_interval: builtins.int = ...,
        disabled: builtins.bool = ...,
        grid_aggregation: global___Downsampling.GridAggregation.ValueType = ...,
        gap_filling: global___Downsampling.GapFilling.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["disabled", b"disabled", "grid_interval", b"grid_interval", "max_points", b"max_points", "mode", b"mode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["disabled", b"disabled", "gap_filling", b"gap_filling", "grid_aggregation", b"grid_aggregation", "grid_interval", b"grid_interval", "max_points", b"max_points", "mode", b"mode"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["mode", b"mode"]) -> typing.Literal["max_points", "grid_interval", "disabled"] | None: ...

global___Downsampling = Downsampling



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.vpc.v1.route_table_pb2
import yandex.cloud.vpc.v1.route_table_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class RouteTableServiceStub:
    """A set of methods for managing RouteTable resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.route_table_service_pb2.GetRouteTableRequest,
        yandex.cloud.vpc.v1.route_table_pb2.RouteTable,
    ]
    """Returns the specified RouteTable resource.

    To get the list of available RouteTable resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.route_table_service_pb2.ListRouteTablesRequest,
        yandex.cloud.vpc.v1.route_table_service_pb2.ListRouteTablesResponse,
    ]
    """Retrieves the list of RouteTable resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.route_table_service_pb2.CreateRouteTableRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a route table in the specified folder and network.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.route_table_service_pb2.UpdateRouteTableRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified route table.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.route_table_service_pb2.DeleteRouteTableRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified route table."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.route_table_service_pb2.ListRouteTableOperationsRequest,
        yandex.cloud.vpc.v1.route_table_service_pb2.ListRouteTableOperationsResponse,
    ]
    """List operations for the specified route table."""

    Move: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.route_table_service_pb2.MoveRouteTableRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Move route table to another folder."""

class RouteTableServiceAsyncStub:
    """A set of methods for managing RouteTable resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.route_table_service_pb2.GetRouteTableRequest,
        yandex.cloud.vpc.v1.route_table_pb2.RouteTable,
    ]
    """Returns the specified RouteTable resource.

    To get the list of available RouteTable resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.route_table_service_pb2.ListRouteTablesRequest,
        yandex.cloud.vpc.v1.route_table_service_pb2.ListRouteTablesResponse,
    ]
    """Retrieves the list of RouteTable resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.route_table_service_pb2.CreateRouteTableRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a route table in the specified folder and network.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.route_table_service_pb2.UpdateRouteTableRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified route table.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.route_table_service_pb2.DeleteRouteTableRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified route table."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.route_table_service_pb2.ListRouteTableOperationsRequest,
        yandex.cloud.vpc.v1.route_table_service_pb2.ListRouteTableOperationsResponse,
    ]
    """List operations for the specified route table."""

    Move: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.route_table_service_pb2.MoveRouteTableRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Move route table to another folder."""

class RouteTableServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing RouteTable resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.vpc.v1.route_table_service_pb2.GetRouteTableRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.route_table_pb2.RouteTable, collections.abc.Awaitable[yandex.cloud.vpc.v1.route_table_pb2.RouteTable]]:
        """Returns the specified RouteTable resource.

        To get the list of available RouteTable resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.vpc.v1.route_table_service_pb2.ListRouteTablesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.route_table_service_pb2.ListRouteTablesResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.route_table_service_pb2.ListRouteTablesResponse]]:
        """Retrieves the list of RouteTable resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.vpc.v1.route_table_service_pb2.CreateRouteTableRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a route table in the specified folder and network.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.vpc.v1.route_table_service_pb2.UpdateRouteTableRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified route table.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.vpc.v1.route_table_service_pb2.DeleteRouteTableRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified route table."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.vpc.v1.route_table_service_pb2.ListRouteTableOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.route_table_service_pb2.ListRouteTableOperationsResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.route_table_service_pb2.ListRouteTableOperationsResponse]]:
        """List operations for the specified route table."""

    @abc.abstractmethod
    def Move(
        self,
        request: yandex.cloud.vpc.v1.route_table_service_pb2.MoveRouteTableRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Move route table to another folder."""

def add_RouteTableServiceServicer_to_server(servicer: RouteTableServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DatasetInfo(google.protobuf.message.Message):
    """Information about the dataset."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DatasetInfo._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: DatasetInfo._Status.ValueType  # 0
        DRAFT: DatasetInfo._Status.ValueType  # 1
        VALIDATING: DatasetInfo._Status.ValueType  # 2
        READY: DatasetInfo._Status.ValueType  # 3
        INVALID: DatasetInfo._Status.ValueType  # 4
        DELETING: DatasetInfo._Status.ValueType  # 5

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Status of the dataset."""

    STATUS_UNSPECIFIED: DatasetInfo.Status.ValueType  # 0
    DRAFT: DatasetInfo.Status.ValueType  # 1
    VALIDATING: DatasetInfo.Status.ValueType  # 2
    READY: DatasetInfo.Status.ValueType  # 3
    INVALID: DatasetInfo.Status.ValueType  # 4
    DELETING: DatasetInfo.Status.ValueType  # 5

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DATASET_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TASK_TYPE_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    ROWS_FIELD_NUMBER: builtins.int
    SIZE_BYTES_FIELD_NUMBER: builtins.int
    CREATED_BY_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    """ID of the dataset."""
    folder_id: builtins.str
    """Folder ID of the dataset."""
    name: builtins.str
    """Name of the dataset."""
    description: builtins.str
    """Description of the dataset."""
    metadata: builtins.str
    """Metadata of the dataset."""
    status: global___DatasetInfo.Status.ValueType
    """Status of the dataset."""
    task_type: builtins.str
    """Task type of the dataset."""
    rows: builtins.int
    """Number of rows in the dataset."""
    size_bytes: builtins.int
    """Size of the dataset."""
    created_by_id: builtins.str
    """User ID of the dataset's creator."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Create dataset timestamp."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Update dataset timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels of the dataset"""

    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        metadata: builtins.str = ...,
        status: global___DatasetInfo.Status.ValueType = ...,
        task_type: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        rows: builtins.int = ...,
        size_bytes: builtins.int = ...,
        created_by_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "created_by_id", b"created_by_id", "dataset_id", b"dataset_id", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "metadata", b"metadata", "name", b"name", "rows", b"rows", "size_bytes", b"size_bytes", "status", b"status", "task_type", b"task_type", "updated_at", b"updated_at"]) -> None: ...

global___DatasetInfo = DatasetInfo

@typing.final
class ValidationError(google.protobuf.message.Message):
    """Information about dataset validation error."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_FIELD_NUMBER: builtins.int
    ERROR_DESCRIPTION_FIELD_NUMBER: builtins.int
    ROW_NUMBERS_FIELD_NUMBER: builtins.int
    error: builtins.str
    """Name of the validation error."""
    error_description: builtins.str
    """Description of the validation error."""
    @property
    def row_numbers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """Row numbers in which the error occurred."""

    def __init__(
        self,
        *,
        error: builtins.str = ...,
        error_description: builtins.str = ...,
        row_numbers: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["error", b"error", "error_description", b"error_description", "row_numbers", b"row_numbers"]) -> None: ...

global___ValidationError = ValidationError
